@@ -4,7 +4,8 @@
  *
  * Author:  Luciano Wolf (luciano.wolf@indt.org.br)
  *
- * Copyright (C) 2005 INdT - Instituto Nokia de Tecnologia
+ * Copyright (C) 2006 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2005-2006 INdT - Instituto Nokia de Tecnologia
  * http://www.indt.org.br
  *
  * This program is free software; you can redistribute it and/or
@@ -72,6 +73,8 @@ GsfXMLInNS gsf_ooo_ns[] = {
 	GSF_XML_IN_NS (OO_NS_DR3D,	"urn:oasis:names:tc:opendocument:xmlns:dr3d:1.0"),
 	GSF_XML_IN_NS (OO_NS_FORM,	"urn:oasis:names:tc:opendocument:xmlns:form:1.0"),
 	GSF_XML_IN_NS (OO_NS_SCRIPT,	"urn:oasis:names:tc:opendocument:xmlns:script:1.0"),
+	GSF_XML_IN_NS (OO_NS_PRESENT,	"urn:oasis:names:tc:opendocument:xmlns:presentation:1.0"),
+
 	GSF_XML_IN_NS (OO_NS_DC,	"http://purl.org/dc/elements/1.1/"),
 	GSF_XML_IN_NS (OO_NS_OOO,	"http://openoffice.org/2004/office"),
 	GSF_XML_IN_NS (OO_NS_OOOW,	"http://openoffice.org/2004/writer"),
@@ -187,7 +190,8 @@ static GsfXMLInNode const gsf_opendoc_meta_dtd[] = {
  *
  * Read an OpenDocument metadata stream from @input and store the properties
  * into @md.  Overwrite any existing properties with the same id.
- * Returns a GError if there is a problem.
+ *
+ * Returns: a GError if there is a problem.
  **/
 GError *
 gsf_opendoc_metadata_read (GsfInput *input, GsfDocMetaData *md)
