@@ -1,7 +1,8 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gsf-output-iconv.h: wrapper to convert character sets.
  *
- * Copyright (C) 2005 Morten Welinder (terra@gnome.org)
+ * Copyright (C) 2005-2006 Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -14,14 +15,14 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
 #ifndef GSF_OUTPUT_ICONV_H
 #define GSF_OUTPUT_ICONV_H
 
-#include "gsf-output.h"
+#include <gsf/gsf-output.h>
 
 G_BEGIN_DECLS
 
@@ -35,7 +36,9 @@ typedef struct {
 
 typedef struct _GsfOutputIconv GsfOutputIconv;
 
-GType	   gsf_output_iconv_get_type (void);
+GType gsf_output_iconv_get_type      (void) G_GNUC_CONST;
+/* void  gsf_output_iconv_register_type (GTypeModule *module); glib dynamic types are not thread safe */
+
 GsfOutput *gsf_output_iconv_new      (GsfOutput *sink, char const *dst, char const *src);
 
 G_END_DECLS
